from enum import Enum


class Vertragsart(str, Enum):
    """
    Aufzählung der Vertragsarten.
    """

    ENERGIELIEFERVERTRAG = "ENERGIELIEFERVERTRAG"
    NETZNUTZUNGSVERTRAG = "NETZNUTZUNGSVERTRAG"
    BILANZIERUNGSVERTRAG = "BILANZIERUNGSVERTRAG"
    MESSSTELLENBETRIEBSVERTRAG = "MESSSTELLENBETRIEBSVERTRAG"
    BUENDELVERTRAG = "BUENDELVERTRAG"
