from enum import Enum


class Regionskriteriumtyp(str, Enum):
    """
    Klassifizierung der Kriterien für eine regionale Eingrenzung.
    """

    BUNDESLANDKENNZIFFER = "BUNDESLANDKENNZIFFER"
    BUNDESLAND_NAME = "BUNDESLAND_NAME"
    MARKTGEBIET_NUMMER = "MARKTGEBIET_NUMMER"
    MARKTGEBIET_NAME = "MARKTGEBIET_NAME"
    REGELGEBIET_NUMMER = "REGELGEBIET_NUMMER"
    REGELGEBIET_NAME = "REGELGEBIET_NAME"
    NETZ_STROM = "NETZ_STROM"
    NETZ_GAS = "NETZ_GAS"
    NETZBETREIBER_NUMMER_STROM = "NETZBETREIBER_NUMMER_STROM"
    NETZBETREIBER_NUMMER_GAS = "NETZBETREIBER_NUMMER_GAS"
    NETZBETREIBER_NAME_STROM = "NETZBETREIBER_NAME_STROM"
    NETZBETREIBER_NAME_GAS = "NETZBETREIBER_NAME_GAS"
    BILANZIERUNGS_GEBIET_NUMMER = "BILANZIERUNGS_GEBIET_NUMMER"
    MSB_NUMMER = "MSB_NUMMER"
    MSB_NAME = "MSB_NAME"
    VERSORGER_NUMMER = "VERSORGER_NUMMER"
    VERSORGER_NAME = "VERSORGER_NAME"
    GRUNDVERSORGER_NUMMER_STROM = "GRUNDVERSORGER_NUMMER_STROM"
    GRUNDVERSORGER_NAME_STROM = "GRUNDVERSORGER_NAME_STROM"
    GRUNDVERSORGER_NUMMER_GAS = "GRUNDVERSORGER_NUMMER_GAS"
    GRUNDVERSORGER_NAME_GAS = "GRUNDVERSORGER_NAME_GAS"
    KREIS_NAME = "KREIS_NAME"
    KREISKENNZIFFER = "KREISKENNZIFFER"
    GEMEINDE_NAME = "GEMEINDE_NAME"
    GEMEINDEKENNZIFFER = "GEMEINDEKENNZIFFER"
    POSTLEITZAHL = "POSTLEITZAHL"
    ORT = "ORT"
    POSTORT = "POSTORT"
    EINWOHNERZAHL_GEMEINDE = "EINWOHNERZAHL_GEMEINDE"
    EINWOHNERZAHL_ORT = "EINWOHNERZAHL_ORT"
    KM_UMKREIS = "KM_UMKREIS"
    BUNDESWEIT = "BUNDESWEIT"
    PLZ_BEREICH = "PLZ_BEREICH"
